@@ -22,6 +22,10 @@
 #ifndef FLATPAK_ERROR_H
 #define FLATPAK_ERROR_H
 
+#if !defined(__FLATPAK_H_INSIDE__) && !defined(FLATPAK_COMPILATION)
+#error "Only <flatpak.h> can be included directly."
+#endif
+
 #include <glib.h>
 
 G_BEGIN_DECLS
@@ -30,12 +34,23 @@ G_BEGIN_DECLS
  * FlatpakError:
  * @FLATPAK_ERROR_ALREADY_INSTALLED: App/runtime is already installed
  * @FLATPAK_ERROR_NOT_INSTALLED: App/runtime is not installed
+ * @FLATPAK_ERROR_ONLY_PULLED: App/runtime was only pulled into the local
+ *                             repository but not installed.
+ * @FLATPAK_ERROR_DIFFERENT_REMOTE: The App/Runtime is already installed, but from a different remote.
+ * @FLATPAK_ERROR_ABORTED: The transaction was aborted (returned TRUE in operation-error signal).
+ * @FLATPAK_ERROR_SKIPPED: The App/Runtime install was skipped due to earlier errors.
+ * @FLATPAK_ERROR_NEED_NEW_FLATPAK: The App/Runtime needs a more recent version of flatpak.
  *
  * Error codes for library functions.
  */
 typedef enum {
   FLATPAK_ERROR_ALREADY_INSTALLED,
   FLATPAK_ERROR_NOT_INSTALLED,
+  FLATPAK_ERROR_ONLY_PULLED,
+  FLATPAK_ERROR_DIFFERENT_REMOTE,
+  FLATPAK_ERROR_ABORTED,
+  FLATPAK_ERROR_SKIPPED,
+  FLATPAK_ERROR_NEED_NEW_FLATPAK,
 } FlatpakError;
 
 #define FLATPAK_ERROR flatpak_error_quark ()
